function [S_br, bvf] = bepsii_brine(i_cores, T_i, S_i, Nr, Ndmax)

%=========================================================================================================
%
% bepsii_brine     : Compute Brine characteristics from a series of cores
%
% IN
%
% i_cores          : a series of input ice cores
% T_i(Nr,Ndmax)    : temperature on this series of ice cores
% S_i(Nr,Ndmax)    : bulk salinity on this series of ice cores
%
% OUT
% 
% S_br(Nr,Ndmax)   : brine salinity
% bvf(Nr,Ndmax)    : brine volume fraction
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Oct 2015, Paris-Lille train)
%
%=========================================================================================================

N_cores = size(i_cores,2);
disp ({' * bepsii_brine * '})

S_br = NaN(Nr,Ndmax);
bvf  = NaN(Nr,Ndmax);

% Brine Salinity (regression of Assur 58 by Notz 2005; valid above -22.xC)
zT2             = T_i(i_cores,:) .* T_i(i_cores,:);
zT3             = T_i(i_cores,:) .* zT2;
S_br(i_cores,:) = -21.4 * T_i(i_cores,:) ...
                  - 0.886 * zT2 ...
                  - 0.017 * zT3;

% Brine volume fraction (Notz 2005)
teos_beta = 7.9e-4;
rhow      = 1027.;

for i = 1: N_cores 
    ii     = i_cores(i);
    zrhoi  = 916.8 - 0.1403 * T_i(ii,:);
    zrhobr = rhow * ( 1. + teos_beta * ( S_br(ii,:) - 34. ) );
    zr     = zrhoi(1,:) ./ zrhobr(1,:);
    znum   = zr(1,:) .* S_i(ii,:);
    zden   = S_br(ii,:) + S_i(ii,:) .* ( zr(1,:) - 1 );
    bvf(ii,:) = znum(1,:) ./ zden(1,:);
end