function [CO2,HCO3,CO3,DIC,Hplus,pH] = bepsii_carb_convert(Nr,Ndmax,S,TA,pCO2,Kw,K1,K2,Kb,Kh)

%=========================================================================================================
%
% bepsii_carb_csts :   computes carbonate system equilibrium constants
%
% Directly based on csys3.m by Zeebe and Wolf-Gladrow (2001)
%
% IN
%
% S                : (Brine) salinity in g/kg
% TA               : Total Alkalinity in mol/kg
% pCO2             : pCO2 in atm
%
% Constants (see if we move into)
%
% KW               : Water dissociation constant
% K1               : 1st CO2 dissociation constant
% K2               : 2nd CO2 dissociation constant
% Kb               : Boron dissociation constant
% Kh               : CO2 solubility in salt water
%
% OUT
%
% CO2              : aqueous CO2
% HCO3             : bicarbonate (HCO3-)
% CO3              : carbonate (CO32-)
% DIC              : dissolved inorganic carbon
% Hplus            : H+
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Sep 2015, Sheffield-Brussels)
%
%=========================================================================================================

%
% only flag 4 developed until now... possible to do more of course
%

Hplus = zeros(Nr,Ndmax);
    
bor = 1.*(416.*(S/35.))* 1.e-6;   % (mol/kg), DOE94
CO2 = Kh .* pCO2;

p4 = 1.;              
p3 = Kb+TA;
p2 = TA.*Kb-CO2.*K1-Kb.*bor-Kw;
p1 = -CO2.*Kb.*K1-CO2*2 .*K1.*K2-Kw.*Kb;
p0 = -2.*CO2.*Kb.*K1.*K2;

for i = 1:Nr;
    for j = 1:Ndmax;
        if ( ~isnan(p0(i,j)) & ~isnan(p1(i,j)) & ~isnan(p2(i,j)) & ~isnan(p3(i,j)) );
            i
            j
            p = [ p4 p3(i,j) p2(i,j) p1(i,j) p0(i,j) ]
            r = roots(p)
            Hplus(i,j) = max(real(r));
        end;
    end
end

DIC  = CO2.*( 1. + K1./Hplus + K1.*K2./Hplus./Hplus );
HCO3 = DIC./( 1. + Hplus ./K1 + K2./ Hplus );
CO3  = DIC./( 1 + Hplus ./K2 + Hplus .* Hplus ./K1 ./K2);
pH   = -log10(Hplus);

end