function [Kw,K1,K2,Kb,Kh] = bepsii_carb_csts(Nr,Tc,S)

%=========================================================================================================
%
% bepsii_carb_csts :   computes carbonate system equilibrium constants
%
% Directly based on csys3.m by Zeebe and Wolf-Gladrow (2001)
%
% IN
%
% Nr               : number of records found in the directory
% Tc               : Temperature in Celsius
% S                : Brine salinity in g/kg
%
% OUT
%
% carbonate constants
% KW
% K1
% K2
% Kb
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Sep 2015, Sheffield-Brussels)
%
%=========================================================================================================
phflag = 0          % 0-total, 1-free
k_flag = {'Mehrbach'} % 'Mehrbach' or 'Roy'
% 
% K1=zeros(1,Nr);
% K2=zeros(1,Nr);
% Kb=zeros(1,Nr);
% Kw=zeros(1,Nr);

%--------------------------------------------------
% Convert input variables into relevant quantities
%--------------------------------------------------

Tk = 273.15;                                         % Conversion constant for C->K
T  = Tc + Tk;                                        % TC [C]; T[K]
Cl = S ./ 1.80655; cl3 = Cl.^(1/3);                   % Cl = chlorinity; S = salinity (per mille)
ION = 0.00147 + 0.03592 * Cl + 0.000068 .* Cl .* Cl;  % Ionic strength
iom0 = 19.924 .*S ./ (1000.-1.005.*S);
S_T = 0.14/96.062/1.80655.*S;                         % (mol/kg soln) total sulfate

%---------------------------------
% Kw: water dissociation constant
%---------------------------------
% Millero (1995) (in Dickson and Goyet (1994, Chapter 5, p.18))
% K_w in mol/kg-soln.
                                                     
tmp1 = -13847.26./T + 148.96502 - 23.6521 .* log(T);
tmp2 = + (118.67./T - 5.977 + 1.0495.*log(T)).*sqrt(S) - 0.01615.*S;
lnKw =  tmp1 + tmp2;

if phflag == 0; % total scale
   Kw  = exp(lnKw);
end;
if phflag == 1; % free scale
   lnKw = lnKw-log(total2free);
   Kw  = exp(lnKw);
end;

%---------------------------------
% K1: First dissociation constant
%---------------------------------
%
% [H^+] [HCO_3^-] / [CO2] = K_1

%--- K1 (Roy et al 93) ---
% (Roy et al., 1993 in Dickson and Goyet, 1994, Chapter 5, p. 14)

if ( isequal(k_flag,{'Roy'}) );
   
    tmp1 = 2.83655 - 2307.1266 ./ T - 1.5529413 .* log(T);
    tmp2 =         - (0.20760841 + 4.0484 ./ T) .* sqrt(S);
    tmp3 =         + 0.08468345 .* S - 0.00654208 .* S .* sqrt(S);   
    tmp4 =         + log(1 - 0.001005 .* S);

    lnK1roy = tmp1 + tmp2 + tmp3 + tmp4;
    K1 = 0;

    if phflag == 0;
       K1 = exp(lnK1roy);
    end;
    if phflag == 1;
       lnK1roy = lnK1roy-log(total2free);
       K1 = exp(lnK1roy);
    end;

end

%--- K1 (Mehrbach et al 73)   
% Mehrbach et al (1973) refit by Lueker et al. (2000).

if ( isequal(k_flag,{'Mehrbach'}) );
    
    pK1mehr = 3633.86./T - 61.2172 + 9.6777.*log(T) - 0.011555.*S + 0.0001152.*S.*S;

    if phflag == 0;
        K1  = 10.^(-pK1mehr);
    end;
    if phflag == 1;
        lnK1mehr = log(10^(-pK1mehr))-log(total2free);
        K1   = exp(lnK1mehr);
    end;

end;

%----------------------------------
% K2: Second dissociation constant
%----------------------------------
%
%   [H^+] [CO_3^--] / [HCO_3^-] = K_2
%
%--- K2 (Roy et al 93) ---
% (Roy et al., 1993 in Dickson and Goyet, 1994, Chapter 5, p. 14)

if ( isequal(k_flag,{'Roy'}) );

    tmp1 = -9.226508 - 3351.6106 ./ T - 0.2005743 .* log(T);
    tmp2 = (-0.106901773 - 23.9722 ./ T) .* sqrt(S);
    tmp3 = 0.1130822 .* S - 0.00846934 .* S.^1.5 + log(1 - 0.001005 * S);

    lnK2roy = tmp1 + tmp2 + tmp3;

    if phflag == 0;
       K2  = exp(lnK2roy);
    end;
    if phflag == 1;
       lnK2roy = lnK2roy-log(total2free);
       K2   = exp(lnK2roy);
    end;

end;

%--- K2 (Mehrbach et al 73) ---
% Mehrbach et al. (1973) refit by Lueker et al. (2000).

if ( isequal(k_flag,{'Mehrbach'}) );

    pK2mehr = 471.78./T + 25.9290 - 3.16967.*log(T) - 0.01781.*S + 0.0001122.*S.*S;

    if phflag == 0;
         K2  = 10.^(-pK2mehr);
    end;
    if phflag == 1;
        lnK2mehr = log(10^(-pK2mehr))-log(total2free);
        K2   = exp(lnK2mehr);
    end;

end;

%----------------------------------
% Kb: Boric acid dissociation
%----------------------------------

%  Kbor = [H+][B(OH)4-]/[B(OH)3]
% (Dickson, 1990 in Dickson and Goyet, 1994, Chapter 5, p. 14)

tmp1 =  (-8966.90-2890.53*sqrt(S)-77.942*S+1.728*S.^(3./2.)-0.0996*S.*S);
tmp2 =   +148.0248+137.1942*sqrt(S)+1.62142*S;
tmp3 = +(-24.4344-25.085*sqrt(S)-0.2474*S).*log(T);

lnKb = tmp1 ./ T + tmp2 + tmp3 + 0.053105*sqrt(S).*T;

if phflag == 0;
   Kb   = exp(lnKb);
end;
if phflag == 1;
   lnKb = lnKb-log(total2free);
   Kb   = exp(lnKb);
end;

%------------------------------------------------
% Kh: CO2 dissolution in salt water (solubility)
%------------------------------------------------

% CO2(g) <-> CO2(aq.)
% Kh      = [CO2]/ p CO2
% Weiss (1974)   [mol/kg/atm]

tmp = 9345.17 ./ T - 60.2409 + 23.3585 * log(T/100.);
nKhwe74 = tmp + S.*(0.023517-0.00023656*T+0.0047036e-4*T.*T);

tmpKh1= 9050.69 ./ T - 58.0931 + 22.2940 * log(T/100.);
nKhwe74l = tmpKh1 + S .* (0.027766-0.00025888*T+0.0050578e-4 * T .* T);

Kh= exp(nKhwe74);
