function [I_var, Nc_int, k_int] = bepsii_integrate(Nr, Ndmax, var_name, var, cl, tsl, dz, Nb, min_sampling, i_squeeze )

% modified Sep 22, 2016 to add min_sampling and i_squeeze in argument

%=========================================================================================================
%
% bepsii_integrate : integrate a variable (var) vertically, over the entire
%                    core length

%                    if sections are missing, a minimum min_sampling fraction of the core
%                    must be present for integration. If min_sampling is too small, the
%                    integral value will be very bad.
%
%                    the integral is computed by summing tracer contents,
%                    then multiplying by total section lengths and dividing by
%                    core length
%
% IN
%
% Nr               : number of records found in the directory
% Ndmax            : maximum number of depths to investigate in the xls file
% var_name         : name of the variable to integrate
% var(Nr,Ndmax)    : variable to integrate
%
% cl(Nr)           : core length (lower depth of the lowermost section)
% tsl(Nr)          : total length of ice core sections with valid data
% dz(Nr,Ndmax)     : lengths of the ice core sections
% Nb(Nr)           : number of potential core sections for each core
% min_sampling     : [0-1] minimum sampling rate to compute the integral
% i_squeeze        : 1- squeeze the integral if missing sections (multiply by core length & divide by total section length)
%
% OUT
%
% I_var            : vertical integrals
% Nc_int           : number of integrable cores
% k_int(Nc_int)    : addresses of integrable cores
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Lille)
%
%=========================================================================================================

disp ({' * bepsii_integrate : ', char(var_name)})

%min_sampling = 0.3;            % integrability coefficient (depends on application)
mask_int  = zeros(1,Nr);    % integrable core mask
I_var     = zeros(1,Nr);    % integral of the variable of interest

Nc_int = 0;

% Determine integrability, integrate & squeeze the integral
for i=1:Nr;
    
    if isnan(cl(i))==0;   %---Integrable ?
       if (tsl(i) >= min_sampling * cl(i));
          
          mask_int(i) = 1;
          Nc_int = Nc_int + 1;
          
          for k = 1:Nb(i) %---Integrate
             if isnan(var(i,k)) == 0;
                I_var(i) = I_var(i) + var(i,k)*dz(i,k);
             end
          end
          
          if (i_squeeze == 1); 
             I_var(i) = I_var(i) / tsl(i) * cl(i); %--- Squeeze
          end
          
       else
          I_var(i) = nan;
       end
       
    else
       I_var(i) = nan;
    end
    
end

% Number of integrable cores and addresses of the integrated cores
k_int = zeros(1,Nc_int);
ii = 1;
for i=1:Nr
    if mask_int(i)==1;
        k_int(ii) = i;
        ii = ii+1;
    end
end
