function [v2_itp, cpl12, Ncpl, i_cores_cpl, i_cores_nocpl] = ...
    bepsii_interpol_cpl(Nr, Ndmin, Ndmax, i_cores, var1, var2, CoreID, Date, lat, lon, ...
                                                     zm1, dz1, cl1, zm2, dz2, cl2, Nd1, Nd2, Nb1, Nb2)
%
%=========================================================================================================
%
% bepsii_interpol_cpl --- Interpolates var2 on depths corresponding to var1 to make both directly comparable
%                         (e.g. for scatter plots)
%
% Method :
%
% For a series of cores with var1 (i_cores)
% - STEP1: Finds companion cores (comparable latitude, longitude and date) with var2
% - STEP2: Interpolates var2 on the depths of var1
%
% IN
% Nr                   : number of records
% Ndmax                : maximum number of levels
% i_cores              : list of core addresses on which var2 has to be interpolated
% var1(Nr,Ndmax)       : var1 for all cores (including missing values)
% var2(Nr,Ndmax)       : var2 for all cores (including missing values)
% CoreID(Nr)           : Core IDs
% Date(Nr)             : dates for all cores
% lat(Nr)              : latitude for all cores
% lon(Nr)              : longitude for all cores
% Nd1(Nr)              : Number of depths for variable 1
% Nd2(Nr)              : Number of depths for variable 2
%
% OUT
% Ncpl                 : Number of couples of cores found
% cpl12(Ncpl,2)        : ( core address with v1, core address with v2 )
% v2_itp(Ncpl, Ndmax)  : var2 interpolated on var1 depths for all couples found
% i_cores_cpl(Nr)      : list of cores with partner core found
% i_cores_nocpl(Nr)    : list of cores with no partner core found
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Brussels)
%
%=========================================================================================================

hdiff_max = 0.21; % 20 cm of ice thickness maximum difference for colocation

%----------------------------------------
% STEP1: make couples of friends (cpl12)
%----------------------------------------
N_cores = size(i_cores, 2);
zcpl = zeros(Nr,2);
Ncpl = 0;

for i=1:N_cores
    
    ii = i_cores(i); % real record reference
    
    for j=1:Nr
        % Date, lat, lon, time, thickness
        %if ( ii ~= j );
            if ( Date(ii) == Date(j) && ( abs(lat(ii)-lat(j)) < 1.0e-2 ) ...
                                     && ( abs(lon(ii)-lon(j)) < 1.0e-2 ) ... 
                                     && ( abs(cl1(ii)-cl2(j)) < hdiff_max ) ...
                                     && Nd2(j) > Ndmin );
                                 % can add a thickness criterion too
                %disp({' Cores ', CoreID{ii}, ii, ' and ', CoreID{j}, j, ' are friends ' })
                Ncpl = Ncpl + 1;
                zcpl(Ncpl,1) = ii; % core with v1 but not v2
                zcpl(Ncpl,2) = j;  % friend core v2
                % one core is counted two times
            end
        %end
    end
    
end

% core lists
cpl12(:,:)        = zcpl(1:Ncpl,:);
i_cores_cpl       = zeros(1,Ncpl);
i_cores_cpl(1,:)  = cpl12(:,1);
i_cores_nocpl     = i_cores(~ismember(i_cores,i_cores_cpl));

%--------------------------------------------
% STEP2: Interpolate var2 on cores with var1
%--------------------------------------------
zm1_norm   = NaN(Nr, Ndmax); % normalized depth on which var2 should be interpolated
zv2a       = NaN(1,Ndmax);
v2_itp     = NaN(Nr,Ndmax);

for i = 1: Ncpl
    ii = cpl12(i,1);
    jj = cpl12(i,2);
    
    N1    = Nb1(ii); % number of raw depths for var1
    N2    = Nb2(jj); % number of raw depths for var2
    
    % raw normalized depths for var1
    kk     = 0;
    for k = 1:N1
        if ( ~isnan(var1(ii,k)) );
           kk = kk + 1;
           zm1_norm(ii,kk) = zm1(ii,k) / cl1(ii); % squeeze raw coordinates to reach [0,1]
       end
    end
            
    % total core length for var1
    int_dz1 = 0;
    for k = 1:N1
        if (~isnan(var1(ii,k)));
           int_dz1 = int_dz1 + dz1(ii,k);
        end
    end
    
    % handle missing values in the variable to be interpolated
    int_var2dz_orig = 0;
    int_dz2 = 0;
    kk     = 0;
    for k = 1:N2
        if ( ~isnan(var2(jj,k)) );
           kk = kk + 1;
           zm2_norm(jj,kk) = zm2(jj,k) / cl2(jj); % squeeze raw coordinates to reach [0,1]
           int_var2dz_orig = int_var2dz_orig + var2(jj,k) * dz2(jj,k);  % compute integral in raw coordinates          
           zv2a(1,kk)      = var2(jj,k);
           int_dz2         = int_dz2 + dz2(jj,k); % total core length for var2
        end
    end
  
    % interpolate and renormalize
    zv2            = interp1(zm2_norm(jj,1:Nd2(jj)), zv2a(1,1:Nd2(jj)), zm1_norm(ii,1:Nd1(ii)), 'linear', 'extrap'); % interpolate
    int_var2dz_int = sum(zv2(1,:).*dz1(ii,1:Nd1(ii)))*Nb1(ii)/Nd1(ii);                   % norm of the new profile
    v2_itp(ii,1:Nd1(ii)) = zv2(:) * int_var2dz_orig / int_var2dz_int * int_dz1 / int_dz2; % normalize new profile
    
end