function [var_std, z_std] = bepsii_interpol_std(Nr, Ndmax, Nstd, var_raw, i_var, zm_var_raw, dz_var_raw, cl_var, Nd_var, Nb_var)

%=========================================================================================================
%
% bepsii_interpol_std: interpolate a series of core profiles on a standard
%                      profile (fixed number of depths, equidistant layers)
%                      interpolation should conserve the integral
%
% IN
% Nr                   : number of records
% Ndmax                : maximum number of levels
% Nstd                 : number of levels for the interpolation
% var_raw              : raw data vector
% i_var                : addresses of the acceptable records
% zm_var_raw(Nr,Ndmax) : mean depths of core sections
% dz_var_raw(Nr,Ndmax) : core sections thicknesses
% cl_var(Nr)           : core length
% Nd_var(Nr)           : number of valid sections (excluding missing values)
% Nb_var(Nr)           : total number of sections (including missing values)
%
% OUT
% var_std(Nf,Nstd)     : interpolated array
% z_std(Nstd)          : interpolated depths

%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Brussels)
%
%=========================================================================================================

% Normalized z coordinates
dz         = 1./Nstd;
z_std      = dz/2.:dz:1.-dz/2.;

% Declare arrays
z_raw_norm = NaN(Nr, Ndmax);
zvar       = NaN(1,Ndmax);
var_std    = NaN(Nr, Nstd);

% Interpolation loop
N_var = size(i_var,2); % Number of valid profiles to be interpolated

for i = 1:N_var
 
    ii = i_var(i);     % select valid files
    zN = Nb_var(ii);   % number of raw depths
    kk = 0;
    znorm     = 0;
    ztotal_dz = 0;
    
    if ( zN >= Nstd./4 ); % this threshold is important
    
    for k = 1:zN
       if ( ~isnan(var_raw(ii,k)) );
          kk = kk + 1;
          z_raw_norm(ii,kk) = zm_var_raw(ii,k) / cl_var(ii); % squeeze raw coordinates to reach [0,1]
          znorm   = znorm + var_raw(ii,k) * dz_var_raw(ii,k); % compute integral in raw coordinates
          zvar(1,kk) = var_raw(ii,k);
          ztotal_dz  = ztotal_dz + dz_var_raw(ii,k);
       end
    end
    
    znorm = znorm * cl_var(ii) / ztotal_dz; % renormalize due to missing sections
    
    % call interpolation and impose the vertical integral to be conserved
    %var_std(ii,:) = interp1(z_raw_norm(ii,1:Nd_var(ii)), zvar(1:Nd_var(ii)), z_std, 'linear', 'extrap');
    var_std(ii,:) = interp1(z_raw_norm(ii,1:kk), zvar(1:kk), z_std, 'linear', 'extrap');
    znorm_int     = sum(var_std(ii,:))/Nstd*cl_var(ii);
    var_std(ii,:) = var_std(ii,:) / znorm_int * znorm;
    
    end
    
end


