function [var, z_var, zm_var, dz_var, cl, tsl, Nr, Nd, Nb, Nc, Ncs, k_prof, k_noprof] = ...
    bepsii_read_profile(dir_list, var_name, Ndmin, Ndmax)

% VERSION OK FOR FRIP's logsheets
%=========================================================================================================
%
% bepsii_read_profile: extracts profile data for a given variable in a collection of xls file
%
% IN
% dir_list         : input directory
% var_name         : variable to be read
% Ndmin            : minimum required number of core sections, for a core to be retained
% Ndmax            : maximum number of depths to investigate in the xls file
%
% OUT
% var(Nr,Ndmax)    : array with the read variable
% z_var(Nr,Ndmax+1): depths of core section interfaces
% zm_var(Nr,Ndmax) : mean depth of a core section
% dz_var(Nr,Ndmax) : core section thickness
% cl(Nr)           : core length (lower depth of the lowermost section)
% tsl(Nr)          : total length of ice core sections with valid data
% Nr               : number of records found in the directory
% Nd(Nr)           : number of valid core sections in a record
% Nb(Nr)           : number of potential sections in a record (including missing ones)
% Nc               : Number of cores with valid sections
% Ncs              : Number of valid sections
% k_prof(:)        : addresses of valid records
% k_noprof(:)      : addresses of invalid records
%
%--------------------------------------------------------------------------------------------------------
%
% BEPSII large scale sea ice biogeochemical database analyzer
% By the beloved Martin Vancoppenolle (Aug 2015, Brussels)
%
%=========================================================================================================

disp ({' * bepsii_read_prof : Read ', char(var_name), ' in ', dir_list})
i_system={'MAC'} % or 'PC'

% Number of Records in the directory
file_list = ls(dir_list);

if isequal(i_system,{'MAC'})
    Filename = strsplit(file_list);
    Nr = size(Filename,2) - 1;
end

if isequal(i_system,{'PC'})
    zFilename = cellstr(file_list);
    Nr = size(zFilename,1) - 2;  
    Filename(1:Nr) = zFilename(3:Nr+2);
end

disp ({' ** Number of records : ', Nr })

% Declare variables
var     = zeros(Nr,Ndmax);
zl      = zeros(Nr,Ndmax);
zu      = zeros(Nr,Ndmax);
z_var   = zeros(Nr,Ndmax+1);
zm_var  = zeros(Nr,Ndmax);
dz_var  = zeros(Nr,Ndmax);
cl      = NaN(1,Nr);
tsl     = zeros(1,Nr);
mask    = zeros(1,Nr);
Nd      = zeros(1,Nr); % number of valid core sections in a core
Nb      = zeros(1,Nr); % number of "potential" sections (including inner sections with missing values)

% Variable addresses in the xls file
if isequal(var_name,{'T_i'});     % Ice temperature
    xlsaddr_zm = 'A15:A75';       % Depth of temperature measurement
    xlsaddr    = 'B15:B75';    
elseif isequal(var_name,{'S_i'}); % Ice salinity
    xlsaddr_zl = 'C15:C75';       % lower s.b.
    xlsaddr_zu = 'D15:D75';       % upper ''
    xlsaddr    = 'E15:E75';
elseif isequal(var_name,{'chla'}); % chl-a
    xlsaddr_zl = 'I15:I75';       % lower s.b. % Fripiat
    xlsaddr_zu = 'J15:J75';       % upper ''
    xlsaddr    = 'K15:K75';
elseif isequal(var_name,{'nox'}); % no2+no3
    xlsaddr_zl = 'R15:R75';       % lower s.b. % Fripiat
    xlsaddr_zu = 'S15:S75';       % upper ''
    xlsaddr    = 'T15:T75';
elseif isequal(var_name,{'po4'}); % po4
    xlsaddr_zl = 'AG15:AG75';       % lower s.b. % Fripiat
    xlsaddr_zu = 'AH15:AH75';       % upper ''
    xlsaddr    = 'AI15:AI75';    
elseif isequal(var_name,{'dsi'}); % dsi
    xlsaddr_zl = 'AJ15:AJ75';       % lower s.b. % Fripiat
    xlsaddr_zu = 'AK15:AK75';       % upper ''
    xlsaddr    = 'AL15:AL75';    
elseif isequal(var_name,{'POC'}); % POC
    xlsaddr_zl = 'O15:O75';       % lower s.b.
    xlsaddr_zu = 'P15:P75';       % upper ''
    xlsaddr    = 'Q15:Q75';
elseif isequal(var_name,{'STA'}); % salinity for alkalinity measurement
    xlsaddr_zl = 'AS15:AS75';     % lower s.b.
    xlsaddr_zu = 'AT15:AT75';     % upper ''
    xlsaddr    = 'AU15:AU75';
elseif isequal(var_name,{'TA'});  % unfiltered alkalinity
    xlsaddr_zl = 'AS15:AS75';     % lower s.b.
    xlsaddr_zu = 'AT15:AT75';     % upper ''
    xlsaddr    = 'AV15:AV75';
elseif isequal(var_name,{'TAf'}); % filtered alkalinity
    xlsaddr_zl = 'AS15:AS75';     % lower s.b.
    xlsaddr_zu = 'AT15:AT75';     % upper ''
    xlsaddr    = 'AW15:AW75';
elseif isequal(var_name,{'pCO2'});  % unfiltered alkalinity
    xlsaddr_zl = 'BC15:BC75';     % lower s.b.
    xlsaddr_zu = 'BD15:BD75';     % upper ''
    xlsaddr    = 'BI15:BI75';
elseif isequal(var_name,{'DFe'}); % dissolved iron
    xlsaddr_zl = 'AS15:AS75';     % lower s.b.
    xlsaddr_zu = 'AT15:AT75';     % upper ''
    xlsaddr    = 'AU15:AU75';
elseif isequal(var_name,{'TDFe'});  % total dissolvable iron
    xlsaddr_zl = 'AV15:AV75';     % lower s.b.
    xlsaddr_zu = 'AW15:AW75';     % upper ''
    xlsaddr    = 'AX15:AX75';
elseif isequal(var_name,{'PFe'}); % particulate iron
    xlsaddr_zl = 'AY15:AY75';     % lower s.b.
    xlsaddr_zu = 'AZ15:AZ75';     % upper ''
    xlsaddr    = 'BA15:BA75';
end

% Read array
disp ({' ** ... Start reading LOOP (takes time)...'})
for i=1:Nr
   i
   Percent_Complete=(i/Nr)*100
   zfile = [dir_list,'/',char(Filename(i))] % full path of the file
   
   %--- Read profile boundaries (not T variable) ---
   if ~isequal(var_name,{'T_i'});
       % Read lower (zl) and upper (zu) depths;
       [x,x,TXT_zl] = xlsread(zfile,1,xlsaddr_zl);
       [x,x,TXT_zu] = xlsread(zfile,1,xlsaddr_zu);
       
       % Convert to section boundaries (z_var)
       z_var(i,1) = TXT_zu{1};
       for k=1:Ndmax;
          if isnan(TXT_zl{k})==0;
              z_var(i,k+1)  = TXT_zl{k};
              zm_var(i,k)   = (TXT_zl{k}+TXT_zu{k})/2.;
              dz_var(i,k)   = TXT_zl{k}-TXT_zu{k};
              Nb(i) = Nb(i) + 1;
          else
              z_var(i,k+1)  = NaN;
              zm_var(i,k) = NaN;
              dz_var(i,k) = NaN;
          end
       end
   end
   
   %--- Read profile boundaries (T variable) ---%
   if isequal(var_name,{'T_i'});
       % Read mean depth (zm)
       [x,x,TXT_zm] = xlsread(zfile,1,xlsaddr_zm);
       for k=1:Ndmax
          if isnan(TXT_zm{k})==0;
              zm_var(i,k)   = TXT_zm{k};
              Nb(i) = Nb(i) + 1;
          else
              zm_var(i,k) = NaN;
          end
       end
       
       % Convert to section boundaries (z_var)
       % This computation is wrong for the last one ?
       z_var(i,1) = 0.;
       for k=1:Ndmax;
          z_var(i,k+1)  = 2*zm_var(i,k) - z_var(i,k);
          dz_var(i,k)   = z_var(i,k+1) - z_var(i,k);
       end
   end
   
   %--- Extract core length (cl) ---%
   if ( Nb(i) > 0 )
       %if (z_var(i,1) <= 0.)
          cl(i) = z_var(i,Nb(i)+1);
       %end
   end
   
   %--- Read Variable ---%
   [x,x,TXT]=xlsread(zfile,1,xlsaddr);
   for k=1:size(TXT,1)
      if isnan(TXT{k})==0
         zvar(i,k) = TXT{k};
         Nd(i) = Nd(i) + 1;
         tsl(i) = tsl(i) + dz_var(i,k);
      else
         zvar(i,k) = NaN;
      end
   end
   var(i,1:Ndmax)=zvar(i,1:Ndmax);
   
   % Compute mask (1 if core retained, 0 if not)
   if Nd(i) > 0
       mask(i) = 1;
   end

end

% Get Basic Profile Statistics
Ncs = sum(Nd.*mask);
disp ({' ** Total number of valid core sections ', Ncs})

k_prof = find( Nd >= Ndmin ); % addresses of retained profiles
Nc = size(k_prof);
Nc = Nc(2);
disp ({' ** Number of cores with valid sections ', Nc})

k_noprof = find( Nd < Ndmin ); % addresses of excluded profiles
Nc_excluded = size(k_noprof);
Nc_excluded = Nc_excluded(2);
disp ({' ** Number of cores excluded ', Nc_excluded})






